try_remove_dir

Function try_remove_dir 

pub fn try_remove_dir<P>(path: P) -> Result<bool>
where P: AsRef<Path>,
Try to remove a dir at the given path.

Returns

Returns Ok(true) if the dir was removed. Returns Ok(false) if the dir did not exist. Returns and error if there was an error removing the dir.